@@ -7,7 +7,7 @@
 #  define AVOGADROQUANTUMIO_NO_EXPORT
 #else
 #  ifndef AVOGADROQUANTUMIO_EXPORT
-#    ifdef AvogadroQuantumIO_EXPORTS
+#    ifdef QuantumIO_EXPORTS
         /* We are building this library */
 #      define AVOGADROQUANTUMIO_EXPORT __attribute__((visibility("default")))
 #    else
@@ -33,6 +33,7 @@
 #  define AVOGADROQUANTUMIO_DEPRECATED_NO_EXPORT AVOGADROQUANTUMIO_NO_EXPORT AVOGADROQUANTUMIO_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef AVOGADROQUANTUMIO_NO_DEPRECATED
 #    define AVOGADROQUANTUMIO_NO_DEPRECATED
